@@ -1,5 +1,4 @@
-#ifndef PERMUTATIONS_REP_H
-#define PERMUTATIONS_REP_H
+#pragma once
 
 #include "NextPermSectionRep.h"
 #include "PermuteHelper.h"
@@ -7,12 +6,13 @@
 
 template <typename T>
 void PermuteRep(T* mat, const std::vector<T> &v,
-                std::vector<int> &z, int n, int m, int nRows) {
+                std::vector<int> &z, std::size_t n,
+                std::size_t m, std::size_t nRows) {
 
-    for (int count = 0, maxInd = n - 1,
+    for (std::size_t count = 0, maxInd = n - 1,
          lastCol = m - 1; count < nRows; ++count) {
 
-        for (int j = 0; j < m; ++j) {
+        for (std::size_t j = 0; j < m; ++j) {
             mat[count + j * nRows] = v[z[j]];
         }
 
@@ -22,12 +22,13 @@ void PermuteRep(T* mat, const std::vector<T> &v,
 
 template <typename T>
 void PermuteRep(RcppParallel::RMatrix<T> &mat, const std::vector<T> &v,
-                std::vector<int> &z, int n, int m, int strt, int nRows) {
+                std::vector<int> &z, std::size_t n, std::size_t m,
+                std::size_t strt, std::size_t nRows) {
 
-    for (int count = strt, maxInd = n - 1,
+    for (std::size_t count = strt, maxInd = n - 1,
          lastCol = m - 1; count < nRows; ++count) {
 
-        for (int j = 0; j < m; ++j) {
+        for (std::size_t j = 0; j < m; ++j) {
             mat(count, j) = v[z[j]];
         }
 
@@ -36,17 +37,15 @@ void PermuteRep(RcppParallel::RMatrix<T> &mat, const std::vector<T> &v,
 }
 
 void PermuteRep(SEXP mat, SEXP v, std::vector<int> &z,
-                int n, int m, int nRows) {
+                std::size_t n, std::size_t m, std::size_t nRows) {
 
-    for (int count = 0, maxInd = n - 1,
+    for (std::size_t count = 0, maxInd = n - 1,
          lastCol = m - 1; count < nRows; ++count) {
 
-        for (int j = 0; j < m; ++j) {
+        for (std::size_t j = 0; j < m; ++j) {
             SET_STRING_ELT(mat, count + j * nRows, STRING_ELT(v, z[j]));
         }
 
         NextSecRep(z, maxInd, lastCol);
     }
 }
-
-#endif
