@@ -1,5 +1,4 @@
-#ifndef PERMUTE_MANAGER_H
-#define PERMUTE_MANAGER_H
+#pragma once
 
 #include "cpp11/R.hpp"
 
@@ -20,5 +19,3 @@ void PermuteParallel(RcppParallel::RMatrix<T> &mat, const std::vector<T> &v,
 void PermuteCharacter(SEXP mat, SEXP v, std::vector<int> &z, int n,
                       int m, int nRows, const std::vector<int> &freqs,
                       bool IsMult, bool IsRep);
-
-#endif
